*Filesystem dominance is all you need*

# refyre, an easy library to manipulate and transport data
    - Homebrew structured data such as DataFrames, and image datasets in a snap of your fingers
    - Supercharge downloading and setting Python environments for repositories in a single file under 20 lines
    - Transport, package, and send/receive data 
